@@ -1,7 +1,7 @@
 /*
  * ndpi_api.h
  *
- * Copyright (C) 2011-24 - ntop.org
+ * Copyright (C) 2011-25 - ntop.org
  *
  * This file is part of nDPI, an open source deep packet inspection
  * library based on the OpenDPI and PACE technology by ipoque GmbH
@@ -153,6 +153,8 @@ extern "C" {
    */
   u_int16_t ndpi_network_ptree_match(struct ndpi_detection_module_struct *ndpi_struct,
 				     struct in_addr *pin);
+  u_int16_t ndpi_network_ptree6_match(struct ndpi_detection_module_struct *ndpi_str,
+				      struct in6_addr *pin);
 
   /**
    * Returns the nDPI protocol id for IP+port-based protocol detection
@@ -486,6 +488,7 @@ extern "C" {
    * @par    string_to_match_len = the length of the string
    * @par    ret_match           = completed returned match information
    * @par    master_protocol_id  = value of the ID associated to the master protocol detected
+   * @par    update_flow_classification = update or not protocol (sub)classification
    * @return the ID of the matched subprotocol
    *
    */
@@ -494,7 +497,8 @@ extern "C" {
 					char *string_to_match,
 					u_int string_to_match_len,
 					ndpi_protocol_match_result *ret_match,
-					u_int16_t master_protocol_id);
+					u_int16_t master_protocol_id,
+					int update_flow_classification);
 
   /**
    * Check if the string content passed match with a protocol
@@ -585,6 +589,25 @@ extern "C" {
   void ndpi_set_proto_category(struct ndpi_detection_module_struct *ndpi_mod,
 			       u_int16_t protoId, ndpi_protocol_category_t protoCategory);
 
+  /**
+   * Find the QoE category for the specified protocol
+   *
+   * @par     ndpi_mod      = the detection module
+   * @par     protoId       = the protocol identifier we're searhing
+   *
+   */
+  ndpi_protocol_qoe_category_t ndpi_find_protocol_qoe(struct ndpi_detection_module_struct *ndpi_str,
+						      u_int16_t protoId);
+
+  /**
+   * Return the name of a RTP payload type
+   *
+   * @par     payload_type     = the RTP payload type
+   * @par     evs_payload_type = EVS payload type (only in case payload_type is EVS)
+   * @return  The symbolic payload type or "Unknown" if not found
+   */
+  const char* ndpi_rtp_payload_type2str(u_int8_t payload_type, u_int32_t evs_payload_type);
+
   /**
    * Check if subprotocols of the specified master protocol are just
    * informative (and not real)
@@ -850,14 +873,14 @@ extern "C" {
   int ndpi_load_risk_domain_file(struct ndpi_detection_module_struct *ndpi_str, const char* path);
 
   /**
-   * Read a file and load the list of malicious JA3 signatures
+   * Read a file and load the list of malicious JA4 signatures
    *
    * @par     ndpi_mod = the detection module
    * @par     path     = the path of the file
    * @return  0 if the file is loaded correctly;
    *          -1 else
    */
-  int ndpi_load_malicious_ja3_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
+  int ndpi_load_malicious_ja4_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
 
   /**
    * Read a file and load the list of malicious SSL certificate SHA1 fingerprints.
@@ -868,6 +891,27 @@ extern "C" {
    */
   int ndpi_load_malicious_sha1_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
 
+  /*
+    Add a new TCP fingerprint
+
+    Return code:
+    0   OK
+    -1  Duplicated fingerprint
+    -2  Unable to add a new entry
+  */
+  int ndpi_add_tcp_fingerprint(struct ndpi_detection_module_struct *ndpi_str,
+			       char *fingerprint, ndpi_os os);
+
+  /**
+   * Read a file and load the list of TCP fingerprints
+   * @par     ndpi_mod = the detection module
+   * @par     path     = the path of the file
+   * @return  0 if the file is loaded correctly;
+   *          -1 else
+   */
+  int load_tcp_fingerprint_file_fd(struct ndpi_detection_module_struct *ndpi_str, FILE *fd);
+  int ndpi_load_tcp_fingerprint_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
+
   /**
    * Get the total number of the supported protocols
    *
@@ -1221,7 +1265,8 @@ extern "C" {
   /* DGA */
   int ndpi_check_dga_name(struct ndpi_detection_module_struct *ndpi_str,
 			  struct ndpi_flow_struct *flow,
-			  char *name, u_int8_t is_hostname, u_int8_t check_subproto);
+			  char *name, u_int8_t is_hostname, u_int8_t check_subproto,
+			  u_int8_t flow_fully_classified);
 
   /* Serializer (supports JSON, TLV, CSV) */
 
@@ -1736,6 +1781,7 @@ extern "C" {
   float ndpi_data_variance(struct ndpi_analyze_struct *s);
   float ndpi_data_stddev(struct ndpi_analyze_struct *s);
   float ndpi_data_mean(struct ndpi_analyze_struct *s);
+  float ndpi_data_jitter(struct ndpi_analyze_struct *s);
   u_int64_t ndpi_data_last(struct ndpi_analyze_struct *s);
   u_int64_t ndpi_data_min(struct ndpi_analyze_struct *s);
   u_int64_t ndpi_data_max(struct ndpi_analyze_struct *s);
@@ -2070,9 +2116,15 @@ extern "C" {
   void ndpi_free_geoip(struct ndpi_detection_module_struct *ndpi_str);
   int ndpi_get_geoip_asn(struct ndpi_detection_module_struct *ndpi_str,
 			 char *ip, u_int32_t *asn);
+  int ndpi_get_geoip_aso(struct ndpi_detection_module_struct *ndpi_str,
+			 char *ip, char *aso, u_int8_t aso_len);
   int ndpi_get_geoip_country_continent(struct ndpi_detection_module_struct *ndpi_str, char *ip,
 				       char *country_code, u_int8_t country_code_len,
 				       char *continent, u_int8_t continent_len);
+  int ndpi_get_geoip_country_continent_city(struct ndpi_detection_module_struct *ndpi_str, char *ip,
+					    char *country_code, u_int8_t country_code_len,
+					    char *continent, u_int8_t continent_len,
+					    char *city, u_int8_t city_len);
 
   /* ******************************* */
 
@@ -2343,7 +2395,7 @@ extern "C" {
 
   /* ******************************* */
 
-  const char* ndpi_print_os_hint(u_int8_t os_hint);
+  const char* ndpi_print_os_hint(ndpi_os os_hint);
 
   /* ******************************* */
 
@@ -2411,7 +2463,20 @@ extern "C" {
    * @return Length of src string
    */
   size_t ndpi_strlcpy(char* dst, const char* src, size_t dst_len, size_t src_len);
-
+  
+  /**
+   * @brief Converts a string from ISO 8859 to UTF-8
+   *
+   * @param in String to convert
+   * @param in_len Source string lenght
+   * @param out Destination string buffer (UTF-8)
+   * @param out_len Length of destination string buffer. It must be at least (2*in_len)+1
+   *
+   * @return The destination string buffer
+   */
+  u_char* ndpi_str_to_utf8(u_char *in, u_int in_len, u_char *out, u_int out_len);
+  
+    
 #ifdef __cplusplus
 }
 #endif
