@@ -26,6 +26,7 @@
 #define NDPI_CURRENT_PROTO NDPI_PROTOCOL_SOMEIP
 
 #include "ndpi_api.h"
+#include "ndpi_private.h"
 
 enum SOMEIP_MESSAGE_TYPES {
   SOMEIP_REQUEST = 0x00,
@@ -92,15 +93,15 @@ static u_int32_t someip_data_cover_32(const u_int8_t *data)
 /**
  * Dissector function that searches SOME/IP headers
  */
-void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
-			 struct ndpi_flow_struct *flow)
+static void ndpi_search_someip(struct ndpi_detection_module_struct *ndpi_struct,
+			       struct ndpi_flow_struct *flow)
 {
   const struct ndpi_packet_struct *packet = &ndpi_struct->packet;
   
   if (packet->payload_packet_len < 16) {
-    NDPI_LOG(NDPI_PROTOCOL_SOMEIP, ndpi_struct, NDPI_LOG_DEBUG,
+    NDPI_LOG_DBG(ndpi_struct,
 	     "Excluding SOME/IP .. mandatory header not found (not enough data for all fields)\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
   
@@ -108,21 +109,12 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
 
   NDPI_LOG_DBG(ndpi_struct, "search SOME/IP\n");
 
-  if (flow->detected_protocol_stack[0] != NDPI_PROTOCOL_UNKNOWN) {
-    return;
-  }
- 
   //we extract the Message ID and Request ID and check for special cases later
   u_int32_t message_id = ntohl(someip_data_cover_32(&packet->payload[0]));
   u_int32_t request_id = ntohl(someip_data_cover_32(&packet->payload[8]));
 
   NDPI_LOG_DBG2(ndpi_struct, "====>>>> SOME/IP Message ID: %08x [len: %u]\n",
 	   message_id, packet->payload_packet_len);
-  if (packet->payload_packet_len < 16) {
-    NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP .. mandatory header not found\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
-    return;
-  }
 
   //####Maximum packet size in SOMEIP depends on the carrier protocol, and I'm not certain how well enforced it is, so let's leave that for round 2####
 
@@ -130,7 +122,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
   u_int32_t someip_len = ntohl(someip_data_cover_32(&packet->payload[4]));
   if (packet->payload_packet_len != (someip_len + 8)) {
     NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP .. Length field invalid!\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 
@@ -138,7 +130,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
   NDPI_LOG_DBG2(ndpi_struct,"====>>>> SOME/IP protocol version: [%d]\n",protocol_version);
   if (protocol_version != LEGAL_PROTOCOL_VERSION){
     NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP .. invalid protocol version!\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 
@@ -152,7 +144,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
       (message_type != SOMEIP_REQUEST_NO_RETURN_ACK) && (message_type != SOMEIP_NOTIFICATION_ACK) && (message_type != SOMEIP_RESPONSE) && 
       (message_type != SOMEIP_ERROR) && (message_type != SOMEIP_RESPONSE_ACK) && (message_type != SOMEIP_ERROR_ACK)) {
     NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP .. invalid message type!\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 
@@ -160,7 +152,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
   NDPI_LOG_DBG2(ndpi_struct,"====>>>> SOME/IP return code: [%d]\n", return_code);
   if ((return_code >= E_RETURN_CODE_LEGAL_THRESHOLD)) {
     NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP .. invalid return code!\n");
-    NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+    NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
     return;
   }
 	
@@ -173,7 +165,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
     }											
     else{
       NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP, invalid header for Magic Cookie\n");
-      NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+      NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
       return;
     }
   }
@@ -187,7 +179,7 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
     }											
     else{
       NDPI_LOG_DBG(ndpi_struct, "Excluding SOME/IP, invalid header for Magic Cookie ACK\n");
-      NDPI_ADD_PROTOCOL_TO_BITMASK(flow->excluded_protocol_bitmask, NDPI_PROTOCOL_SOMEIP);
+      NDPI_EXCLUDE_PROTO(ndpi_struct, flow);
       return;
     }
   }
@@ -202,12 +194,12 @@ void ndpi_search_someip (struct ndpi_detection_module_struct *ndpi_struct,
  * Entry point for the ndpi library
  */
 void init_someip_dissector (struct ndpi_detection_module_struct *ndpi_struct,
-			    u_int32_t *id, NDPI_PROTOCOL_BITMASK *detection_bitmask)
+			    u_int32_t *id)
 {
-  ndpi_set_bitmask_protocol_detection ("SOME/IP", ndpi_struct, detection_bitmask, *id,
+  ndpi_set_bitmask_protocol_detection ("SOME/IP", ndpi_struct, *id,
 				       NDPI_PROTOCOL_SOMEIP,
 				       ndpi_search_someip,
-				       NDPI_SELECTION_BITMASK_PROTOCOL_V4_V6_TCP_OR_UDP_WITH_PAYLOAD,
+				       NDPI_SELECTION_BITMASK_PROTOCOL_V4_V6_TCP_OR_UDP_WITH_PAYLOAD_WITHOUT_RETRANSMISSION,
 				       SAVE_DETECTION_BITMASK_AS_UNKNOWN, ADD_TO_DETECTION_BITMASK);
   *id +=1;
 }
